@@ -11,10 +11,7 @@
 
 package AnalogClock;
 
-use QObject;
-use QPainter;
-use QTimer;
-use QWidget;
+use Qt ();
 
 use slots 'timeout()';
 
@@ -27,8 +24,8 @@ use slots 'timeout()';
 sub new {
     my $self = shift->SUPER::new(@_);
 
-    $$self{'time'} = [ localtime ];			# get current time
-    my $internalTimer = new QTimer($self)->immortal;	# create internal timer
+    $self->{'time'} = [ localtime ];			# get current time
+    my $internalTimer = QTimer->new($self);		# create internal timer
     $self->connect($internalTimer, 'timeout()', 'timeout()');
     $internalTimer->start(5000);		# emit signal every 5 seconds
 
@@ -43,7 +40,7 @@ sub new {
 sub timeout {
     my $self = shift;
 
-    $self->update() if (localtime)[1] != $$self{'time'}[1];
+    $self->update() if (localtime)[1] != $self->{'time'}[1];
 }
 
 
@@ -55,10 +52,10 @@ sub paintEvent {
     my $self = shift;
 
     return unless $self->isVisible();		# it is invisible
-    my $time = $$self{'time'} = [ localtime ];	# save current time
+    my $time = $self->{'time'} = [ localtime ];	# save current time
 
-    my $pts = new QPointArray;
-    my $paint = new QPainter;
+    my $pts = QPointArray->new;
+    my $paint = QPainter->new;
     $paint->begin($self);
     $paint->setBrush($self->foregroundColor());	# fill with foreground color
 
@@ -66,18 +63,18 @@ sub paintEvent {
     my $d = ($self->width() < $self->height()) ?
 	$self->width() : $self->height();	# we want a circular clock
 
-    my $matrix = new QWMatrix;			# setup transformation matrix
+    my $matrix = QWMatrix->new;			# setup transformation matrix
     $matrix->translate($cp->x(), $cp->y());	# origin at widget center
     $matrix->scale($d/1000.0, $d/1000.0);	# scale coordinate system
 
-    my $h_angle = 30*($$time[2]%12-3) + $$time[1]/2;
+    my $h_angle = 30*($time->[2]%12-3) + $time->[1]/2;
     $matrix->rotate($h_angle);			# rotate to draw hour hand
     $paint->setWorldMatrix($matrix);
     $pts->setPoints(-20,0, 0,-20, 300,0, 0,20);
     $paint->drawPolygon($pts);			# draw hour hand
     $matrix->rotate(-$h_angle);			# rotate back to zero
 
-    my $m_angle = ($$time[1]-15)*6;
+    my $m_angle = ($time->[1]-15)*6;
     $matrix->rotate($m_angle);			# rotate to draw minute hand
     $paint->setWorldMatrix($matrix);
     $pts->setPoints(-10,0, 0,-10, 400,0, 0,10);
