@@ -1,14 +1,13 @@
 package Biff;
 
-use QPainter;
-use QWidget;
+use Qt qw(%Widget);
 
 require "bmp.pl";
 
 @ISA = qw(QWidget);
 
 sub new {
-    my $self = shift->SUPER::new(undef, 0, $Flags{Type}{Modal});
+    my $self = shift->SUPER::new(undef, 0, $Widget{Modal});
     my $mailbox = $ENV{MAIL} || "/var/spool/mail/" . getlogin();
 
     $self->startTimer(1000) if -e $mailbox;
@@ -17,9 +16,9 @@ sub new {
     $self->setMaximumSize(48, 48);
     $self->resize(48, 48);
 
-    my $hasNewMail = new QPixmap;
+    my $hasNewMail = QPixmap->new;
     $hasNewMail->loadFromData($hasmail_bmp_data);
-    my $noNewMail = new QPixmap;
+    my $noNewMail = QPixmap->new;
     $noNewMail->loadFromData($nomail_bmp_data);
 
     my $gotMail = 0;
@@ -39,8 +38,8 @@ sub timerEvent {
     my $newState = ($mtime != $lastModified &&
 		    $mtime > $atime) ? 1 : 0;
     if($newState != $gotMail) {
-	$$self{'lastModified'} = $mtime if $gotMail;
-	$$self{'gotMail'} = $newState;
+	$self->{'lastModified'} = $mtime if $gotMail;
+	$self->{'gotMail'} = $newState;
 	$self->repaint(0);
     }
 }
@@ -55,7 +54,7 @@ sub paintEvent {
 
 sub mousePressEvent {
     my $self = shift;
-    my $mtime = (stat $$self{'mailbox'})[9];
+    my $mtime = (stat $self->{'mailbox'})[9];
 
-    $$self{'lastModified'} = $mtime;
+    $self->{'lastModified'} = $mtime;
 }
