@@ -1,12 +1,6 @@
 package Preferences;
 
-use QButtonGroup;
-use QLabel;
-use QLayout;
-use QMultiLineEdit;
-use QRadioButton;
-use QSlider;
-use QTabDialog;
+use Qt qw(%Align %Direction %Orientation);
 
 use slots 'setup()', 'apply()';
 
@@ -14,35 +8,35 @@ use slots 'setup()', 'apply()';
 
 sub new {
     my $self = shift->SUPER::new(@_);
-    my $tab = new QTabDialog(undef, 'top-level dialog')->immortal;
+    my $tab = QTabDialog->new(undef, 'top-level dialog');
     $tab->setCaption('Ugly Tab Dialog');
 
     # set up page one of the tab dialog
-    my $w = new QWidget($tab, 'page one')->immortal;
+    my $w = QWidget->new($tab, 'page one');
 
     # stuff the labels and lineedits into a grid layout
-    my $g = new QGridLayout($w, 2, 2, 5);
+    my $g = QGridLayout->new($w, 2, 2, 5);
 
     # two multilineedits in column 1
-    my $ed1 = new QMultiLineEdit($w)->immortal;
+    my $ed1 = QMultiLineEdit->new($w);
     $g->addWidget($ed1, 0, 1);
     $ed1->setText('');
-    $ed1->setMinimumSize(new QSize(100, 10));
-    my $ed2 = new QMultiLineEdit($w)->immortal;
+    $ed1->setMinimumSize(QSize->new(100, 10));
+    my $ed2 = QMultiLineEdit->new($w);
     $g->addWidget($ed2, 1, 1);
     $ed2->setText('');
-    $ed2->setMinimumSize(new QSize(100, 10));
+    $ed2->setMinimumSize(QSize->new(100, 10));
 
     # let the lineedits stretch
     $g->setColStretch(1, 1);
 
     # two labels in column 0
-    my $l = new QLabel($w)->immortal;
+    my $l = QLabel->new($w);
     $g->addWidget($l, 0, 0);
     $l->setText('&Name');
     $l->setBuddy($ed1);
     $l->setMinimumSize($l->sizeHint());
-    $l = new QLabel($w)->immortal;
+    $l = QLabel->new($w);
     $g->addWidget($l, 1, 0);
     $l->setText('&Email');
     $l->setBuddy($ed2);
@@ -56,25 +50,25 @@ sub new {
     $g->activate();
 
     # that was page one, now for page two, where we use a box layout
-    $w = new QWidget($tab, 'page two')->immortal;
-    my $b = new QBoxLayout($w, $Direction{LeftToRight}, 5)->immortal;
+    $w = QWidget->new($tab, 'page two');
+    my $b = QBoxLayout->new($w, $Direction{LeftToRight}, 5);
 
     # two vertical boxes in the horizontal one
-    my $radioBoxes = new QBoxLayout($Direction{Down})->immortal;
+    my $radioBoxes = QBoxLayout->new($Direction{Down});
     $b->addLayout($radioBoxes);
 
     # fill the leftmost vertical box
-    my $b1 = new QRadioButton($w, 'radio button 1')->immortal;
+    my $b1 = QRadioButton->new($w, 'radio button 1');
     $b1->setText('Male');
     $b1->setMinimumSize($b1->sizeHint());
     $b1->setMaximumSize(500, $b1->minimumSize()->height());
     $radioBoxes->addWidget($b1, $Align{Left}|$Align{Top});
-    my $b2 = new QRadioButton($w, 'radio button 2')->immortal;
+    my $b2 = QRadioButton->new($w, 'radio button 2');
     $b2->setText('Female');
     $b2->setMinimumSize($b2->sizeHint());
     $b2->setMaximumSize(500, $b2->minimumSize()->height());
     $radioBoxes->addWidget($b2, $Align{Left}|$Align{Top});
-    my $b3 = new QRadioButton($w, 'radio button 3')->immortal;
+    my $b3 = QRadioButton->new($w, 'radio button 3');
     $b3->setText('Duo Pack');
     $b3->setMinimumSize($b3->sizeHint());
     $b3->setMaximumSize(500, $b3->minimumSize()->height());
@@ -85,7 +79,7 @@ sub new {
 
     # insert all of the radio boxes into the button group, so they'll
     # switch each other off
-    my $bg = new QButtonGroup->immortal;
+    my $bg = QButtonGroup->new;
     $bg->insert($b1);
     $bg->insert($b2);
     $bg->insert($b3);
@@ -95,24 +89,24 @@ sub new {
 
     # make the central slider
     my $mood =
-	new QSlider($Orientation{Vertical}, $w, 'mood slider')->immortal;
+	QSlider->new($Orientation{Vertical}, $w, 'mood slider');
     $mood->setRange(0, 127);
     $mood->setMinimumSize($mood->sizeHint());
     $mood->setMaximumSize($mood->minimumSize->width(), 500);
     $b->addWidget($mood, $Align{Left}|$Align{Top}|$Align{Bottom});
 
     # make the top and bottom labels for the slider
-    my $labels = new QBoxLayout($Direction{Down})->immortal;
+    my $labels = QBoxLayout->new($Direction{Down});
     $b->addLayout($labels);
     $b->addLayout($labels);
-    $l = new QLabel('Optimistic', $w, 'optimistic')->immortal;
+    $l = QLabel->new('Optimistic', $w, 'optimistic');
     $l->setFixedSize($l->sizeHint());
     $labels->addWidget($l, $Align{Top}|$Align{Left});
 
     # spacing in the middle, so the labels are located right
     $labels->addStretch(1);
 
-    $l = new QLabel('Pessimistic', $w, 'pessimistic')->immortal;
+    $l = QLabel->new('Pessimistic', $w, 'pessimistic');
     $l->setFixedSize($l->sizeHint());
     $labels->addWidget($l, $Align{Bottom}|$Align{Left});
 
