@@ -1,33 +1,27 @@
 package Editor;
 
-use Qt;
-use QEvent;
-use QFileDialog;
-use QMenuBar;
-use QMultiLineEdit;
-use QPopupMenu;
-use QWidget;
+use Qt qw($app %Key);
 
-use slots 'load()', 'loadFile(string)', 'save()', 'create()', 'print()';
+use slots 'load()', 'loadFile(cstring)', 'save()', 'create()', 'print()';
 
 @ISA = qw(QWidget);
 
 sub new {
     my $self = shift->SUPER::new(@_);
 
-    my $m = new QMenuBar($self, 'menu');
-    my $file = new QPopupMenu->setImmortal;
+    my $m = QMenuBar->new($self, 'menu');
+    my $file = QPopupMenu->new;
     $m->insertItem('&File', $file);
 
-    $file->insertItem('New', $self, 'create()', $ALT+$Key{N});
-    $file->insertItem('Open', $self, 'load()', $ALT+$Key{O});
-    $file->insertItem('Save', $self, 'save()', $ALT+$Key{S});
+    $file->insertItem('New', $self, 'create()', $Key{Alt}+$Key{N});
+    $file->insertItem('Open', $self, 'load()', $Key{Alt}+$Key{O});
+    $file->insertItem('Save', $self, 'save()', $Key{Alt}+$Key{S});
     $file->insertSeparator();
-    $file->insertItem('Print', $self, 'print()', $ALT+$Key{P});
+    $file->insertItem('Print', $self, 'print()', $Key{Alt}+$Key{P});
     $file->insertSeparator();
-    $file->insertItem('Quit', $qApp, 'quit()', $ALT+$Key{Q});
+    $file->insertItem('Quit', $app, 'quit()', $Key{Alt}+$Key{Q});
 
-    my $e = new QMultiLineEdit($self, 'editor');
+    my $e = QMultiLineEdit->new($self, 'editor');
 
     @$self{'m', 'e'} = ($m, $e);
     return $self;
