@@ -1,11 +1,6 @@
 package CannonField;
 
-use Qt;
-use QColor;
-use QPainter;
-use QPen;
-use QPixmap;
-use QWidget;
+use Qt qw(%Color %Pen);
 
 use signals 'hit()', 'missed()', 'angleChanged(int)', 'forceChanged(int)';
 use slots 'setAngle(int)', 'setForce(int)', 'shoot()', 'newTarget()';
@@ -16,7 +11,7 @@ sub new {
     my $self = shift->SUPER::new(@_);
 
     @$self{'ang', 'f', 'shooting', 'timerCount', 'shoot_ang', 'shoot_f',
-	   'target'} = (45, 0, 0, 0, 0, 0, new QPoint);
+	   'target'} = (45, 0, 0, 0, 0, 0, QPoint->new);
     $self->newTarget();
 
     return $self;
@@ -32,10 +27,10 @@ sub setAngle {
 
     $degrees = 5 if $degrees < 5;
     $degrees = 70 if $degrees > 70;
-    return if $$self{'ang'} == $degrees;
-    $$self{'ang'} = $degrees;
+    return if $self->{'ang'} == $degrees;
+    $self->{'ang'} = $degrees;
     $self->repaint($self->cannonRect(), 0);
-    emit $self->angleChanged($$self{'ang'});
+    emit $self->angleChanged($self->{'ang'});
 }
 
 sub setForce {
@@ -43,9 +38,9 @@ sub setForce {
     my $newton = shift;
 
     $newton = 0 if $newton < 0;
-    return if $$self{'f'} == $newton;
-    $$self{'f'} = $newton;
-    emit $self->forceChanged($$self{'f'});
+    return if $self->{'f'} == $newton;
+    $self->{'f'} = $newton;
+    emit $self->forceChanged($self->{'f'});
 }
 
 sub shoot {
@@ -53,7 +48,7 @@ sub shoot {
 
     return if $$self{'shooting'};
     @$self{'timerCount', 'shoot_ang', 'shoot_f', 'shooting'} =
-	(0, $$self{'ang'}, $$self{'f'}, 1);
+	(0, $self->{'ang'}, $self->{'f'}, 1);
     $self->startTimer(50);
 }
 
@@ -64,8 +59,8 @@ sub newTarget {
     my $self = shift;
 
     $self->erase($self->targetRect());
-    $$self{'target'} = new QPoint(200 + rand(65536) % 190,
-				  10  + rand(65536) % 255);
+    $self->{'target'} = QPoint->new(200 + rand(65536) % 190,
+				    10  + rand(65536) % 255);
     $self->repaint($self->targetRect());
 }
 
@@ -73,7 +68,7 @@ sub timerEvent {
     my $self = shift;
 
     $self->erase($self->shotRect());
-    $$self{'timerCount'}++;
+    $self->{'timerCount'}++;
 
     my $shotR = $self->shotRect();
 
@@ -93,7 +88,7 @@ sub timerEvent {
 sub paintEvent {
     my $self = shift;
     my $updateR = shift->rect();
-    my $p = new QPainter;
+    my $p = QPainter->new;
     $p->begin($self);
 
     $self->paintCannon($p) if $updateR->intersects($self->cannonRect());
@@ -106,7 +101,7 @@ sub paintEvent {
 sub stopShooting {
     my $self = shift;
 
-    $$self{'shooting'} = 0;
+    $self->{'shooting'} = 0;
     $self->killTimers();
 }
 
@@ -114,7 +109,7 @@ sub paintShot {
     my $self = shift;
     my $p = shift;
 
-    $p->setBrush($black);
+    $p->setBrush($Color{Black});
     $p->setPen($Pen{None});
     $p->drawRect($self->shotRect());
 }
@@ -123,29 +118,29 @@ sub paintTarget {
     my $self = shift;
     my $p = shift;
 
-    $p->setBrush($red);
-    $p->setPen($black);
+    $p->setBrush($Color{Red});
+    $p->setPen($Color{Black});
     $p->drawRect($self->targetRect());
 }
 
-$barrel_rect = new QRect(33, -4, 15, 8);
+$barrel_rect = QRect->new(33, -4, 15, 8);
 
 sub paintCannon {
     my $self = shift;
     my $p = shift;
     my $cr = $self->cannonRect();
-    my $pix = new QPixmap($cr->size());
-    my $tmp = new QPainter;
+    my $pix = QPixmap->new($cr->size());
+    my $tmp = QPainter->new;
 
     $pix->fill($self, $cr->topLeft());
 
     $tmp->begin($pix);
-    $tmp->setBrush($blue);
+    $tmp->setBrush($Color{Blue});
     $tmp->setPen($Pen{None});
 
     $tmp->translate(0, $pix->height() - 1);
-    $tmp->drawPie(new QRect(-35, -35, 70, 70), 0, 90*16);
-    $tmp->rotate(-$$self{'ang'});
+    $tmp->drawPie(QRect->new(-35, -35, 70, 70), 0, 90*16);
+    $tmp->rotate(-$self->{'ang'});
     $tmp->drawRect($barrel_rect);
     $tmp->end();
 
@@ -154,7 +149,7 @@ sub paintCannon {
 
 sub cannonRect {
     my $self = shift;
-    my $r = new QRect(0, 0, 50, 50);
+    my $r = QRect->new(0, 0, 50, 50);
 
     $r->moveBottomLeft($self->rect()->bottomLeft());
     return $r;
@@ -165,9 +160,9 @@ sub shotRect {
 
     my $gravity  = 4;
 
-    my $time     = $$self{'timerCount'}/4.0;
-    my $velocity = $$self{'shoot_f'}/0.7;
-    my $radians  = $$self{'shoot_ang'}*3.14159265/180;
+    my $time     = $self->{'timerCount'}/4.0;
+    my $velocity = $self->{'shoot_f'}/0.7;
+    my $radians  = $self->{'shoot_ang'}*3.14159265/180;
 
     my $velx = $velocity*cos($radians);
     my $vely = $velocity*sin($radians);
@@ -176,17 +171,17 @@ sub shotRect {
     my $x    = $x0 + $velx*$time;
     my $y    = $y0 + $vely*$time - $gravity*$time*$time;
 
-    my $r = new QRect(0, 0, 6, 6);
-    $r->moveCenter(new QPoint(qRound($x), $self->height() - 1 - qRound($y)));
+    my $r = QRect->new(0, 0, 6, 6);
+    $r->moveCenter(QPoint->new($x, $self->height() - 1 - $y));
     return $r;
 }
 
 sub targetRect {
     my $self = shift;
-    my $target = $$self{'target'};
-    my $r = new QRect(0, 0, 20, 10);
+    my $target = $self->{'target'};
+    my $r = QRect->new(0, 0, 20, 10);
 
-    $r->moveCenter(new QPoint($target->x(), $self->height() - 1 -
-			      $target->y()));
+    $r->moveCenter(QPoint->new($target->x(), $self->height() - 1 -
+			       $target->y()));
     return $r;
 }
