@@ -1,12 +1,6 @@
 package CannonField;
 
-use Qt;
-use QColor;
-use QFont;
-use QPainter;
-use QPen;
-use QPixmap;
-use QWidget;
+use Qt qw(%Align %Color %Pen %Weight);
 
 use signals 'hit()', 'missed()', 'angleChanged(int)', 'forceChanged(int)';
 use slots 'setAngle(int)', 'setForce(int)', 'shoot()', 'newTarget()';
@@ -35,10 +29,10 @@ sub setAngle {
 
     $degrees = 5 if $degrees < 5;
     $degrees = 70 if $degrees > 70;
-    return if $$self{'ang'} == $degrees;
-    $$self{'ang'} = $degrees;
+    return if $self->{'ang'} == $degrees;
+    $self->{'ang'} = $degrees;
     $self->repaint($self->cannonRect(), 0);
-    emit $self->angleChanged($$self{'ang'});
+    emit $self->angleChanged($self->{'ang'});
 }
 
 sub setForce {
@@ -46,17 +40,17 @@ sub setForce {
     my $newton = shift;
 
     $newton = 0 if $newton < 0;
-    return if $$self{'f'} == $newton;
-    $$self{'f'} = $newton;
-    emit $self->forceChanged($$self{'f'});
+    return if $self->{'f'} == $newton;
+    $self->{'f'} = $newton;
+    emit $self->forceChanged($self->{'f'});
 }
 
 sub shoot {
     my $self = shift;
 
-    return if $$self{'shooting'};
+    return if $self->{'shooting'};
     @$self{'timerCount', 'shoot_ang', 'shoot_f', 'shooting'} =
-	(0, $$self{'ang'}, $$self{'f'}, 1);
+	(0, $self->{'ang'}, $self->{'f'}, 1);
     $self->startTimer(50);
 }
 
@@ -67,25 +61,25 @@ sub newTarget {
     my $self = shift;
 
     $self->erase($self->targetRect());
-    $$self{'target'} = new QPoint(200 + rand(65536) % 190,
-				  10  + rand(65536) % 255);
+    $self->{'target'} = QPoint->new(200 + rand(65536) % 190,
+				    10  + rand(65536) % 255);
     $self->repaint($self->targetRect());
 }
 
 sub setGameOver {
     my $self = shift;
 
-    return if $$self{'gameEnded'};
-    $self->stopShooting() if $$self{'shooting'};
-    $$self{'gameEnded'} = 1;
+    return if $self->{'gameEnded'};
+    $self->stopShooting() if $self->{'shooting'};
+    $self->{'gameEnded'} = 1;
     $self->repaint();
 }
 
 sub restartGame {
     my $self = shift;
 
-    $self->stopShooting() if $$self{'shooting'};
-    $$self{'gameEnded'} = 0;
+    $self->stopShooting() if $self->{'shooting'};
+    $self->{'gameEnded'} = 0;
     $self->repaint();
 }
 
@@ -93,7 +87,7 @@ sub timerEvent {
     my $self = shift;
 
     $self->erase($self->shotRect());
-    $$self{'timerCount'}++;
+    $self->{'timerCount'}++;
 
     my $shotR = $self->shotRect();
 
@@ -113,13 +107,13 @@ sub timerEvent {
 sub paintEvent {
     my $self = shift;
     my $updateR = shift->rect();
-    my $p = new QPainter;
+    my $p = QPainter->new;
     $p->begin($self);
 
     $self->paintCannon($p) if $updateR->intersects($self->cannonRect());
-    if($$self{'gameEnded'}) {
-	$p->setPen($black);
-	$p->setFont(new QFont('Courier', 48, $Weight{Bold}));
+    if($self->{'gameEnded'}) {
+	$p->setPen($Color{Black});
+	$p->setFont(QFont->new('Courier', 48, $Weight{Bold}));
 	$p->drawText($self->rect(), $Align{Center}, 'Game Over');
     } else {
 	$self->paintShot($p) if $self->isShooting() &&
@@ -132,7 +126,7 @@ sub paintEvent {
 sub stopShooting {
     my $self = shift;
 
-    $$self{'shooting'} = 0;
+    $self->{'shooting'} = 0;
     $self->killTimers();
 }
 
@@ -140,7 +134,7 @@ sub paintShot {
     my $self = shift;
     my $p = shift;
 
-    $p->setBrush($black);
+    $p->setBrush($Color{Black});
     $p->setPen($Pen{None});
     $p->drawRect($self->shotRect());
 }
@@ -149,29 +143,29 @@ sub paintTarget {
     my $self = shift;
     my $p = shift;
 
-    $p->setBrush($red);
-    $p->setPen($black);
+    $p->setBrush($Color{Red});
+    $p->setPen($Color{Black});
     $p->drawRect($self->targetRect());
 }
 
-$barrel_rect = new QRect(33, -4, 15, 8);
+$barrel_rect = QRect->new(33, -4, 15, 8);
 
 sub paintCannon {
     my $self = shift;
     my $p = shift;
     my $cr = $self->cannonRect();
-    my $pix = new QPixmap($cr->size());
-    my $tmp = new QPainter;
+    my $pix = QPixmap->new($cr->size());
+    my $tmp = QPainter->new;
 
     $pix->fill($self, $cr->topLeft());
 
     $tmp->begin($pix);
-    $tmp->setBrush($blue);
+    $tmp->setBrush($Color{Blue});
     $tmp->setPen($Pen{None});
 
     $tmp->translate(0, $pix->height() - 1);
-    $tmp->drawPie(new QRect(-35, -35, 70, 70), 0, 90*16);
-    $tmp->rotate(-$$self{'ang'});
+    $tmp->drawPie(QRect->new(-35, -35, 70, 70), 0, 90*16);
+    $tmp->rotate(-$self->{'ang'});
     $tmp->drawRect($barrel_rect);
     $tmp->end();
 
@@ -180,7 +174,7 @@ sub paintCannon {
 
 sub cannonRect {
     my $self = shift;
-    my $r = new QRect(0, 0, 50, 50);
+    my $r = QRect->new(0, 0, 50, 50);
 
     $r->moveBottomLeft($self->rect()->bottomLeft());
     return $r;
@@ -191,9 +185,9 @@ sub shotRect {
 
     my $gravity  = 4;
 
-    my $time     = $$self{'timerCount'}/4.0;
-    my $velocity = $$self{'shoot_f'}/0.7;
-    my $radians  = $$self{'shoot_ang'}*3.14159265/180;
+    my $time     = $self->{'timerCount'}/4.0;
+    my $velocity = $self->{'shoot_f'}/0.7;
+    my $radians  = $self->{'shoot_ang'}*3.14159265/180;
 
     my $velx = $velocity*cos($radians);
     my $vely = $velocity*sin($radians);
@@ -202,17 +196,17 @@ sub shotRect {
     my $x    = $x0 + $velx*$time;
     my $y    = $y0 + $vely*$time - $gravity*$time*$time;
 
-    my $r = new QRect(0, 0, 6, 6);
-    $r->moveCenter(new QPoint(qRound($x), $self->height() - 1 - qRound($y)));
+    my $r = QRect->new(0, 0, 6, 6);
+    $r->moveCenter(QPoint->new($x, $self->height() - 1 - $y));
     return $r;
 }
 
 sub targetRect {
     my $self = shift;
-    my $target = $$self{'target'};
-    my $r = new QRect(0, 0, 20, 10);
+    my $target = $self->{'target'};
+    my $r = QRect->new(0, 0, 20, 10);
 
-    $r->moveCenter(new QPoint($target->x(), $self->height() - 1 -
-			      $target->y()));
+    $r->moveCenter(QPoint->new($target->x(), $self->height() - 1 -
+			       $target->y()));
     return $r;
 }
