@@ -1,14 +1,6 @@
 package CannonField;
 
-use Qt;
-use QColor;
-use QEvent;
-use QFont;
-use QPainter;
-use QPen;
-use QPixmap;
-use QWidget;
-use QWMatrix;
+use Qt qw(%Align %Button %Color %Pen %Weight);
 
 use POSIX 'math_h';  # No atan() in Perl.
 
@@ -23,7 +15,7 @@ sub new {
 
     @$self{'ang', 'f', 'shooting', 'timerCount', 'shoot_ang', 'shoot_f',
 	   'gameEnded', 'barrelPressed', 'target'} =
-	       (45, 0, 0, 0, 0, 0, 0, 0, new QPoint);
+	       (45, 0, 0, 0, 0, 0, 0, 0, QPoint->new);
     $self->newTarget();
 
     return $self;
@@ -40,10 +32,10 @@ sub setAngle {
 
     $degrees = 5 if $degrees < 5;
     $degrees = 70 if $degrees > 70;
-    return if $$self{'ang'} == $degrees;
-    $$self{'ang'} = $degrees;
+    return if $self->{'ang'} == $degrees;
+    $self->{'ang'} = $degrees;
     $self->repaint($self->cannonRect(), 0);
-    emit $self->angleChanged($$self{'ang'});
+    emit $self->angleChanged($self->{'ang'});
 }
 
 sub setForce {
@@ -51,15 +43,15 @@ sub setForce {
     my $newton = shift;
 
     $newton = 0 if $newton < 0;
-    return if $$self{'f'} == $newton;
-    $$self{'f'} = $newton;
-    emit $self->forceChanged($$self{'f'});
+    return if $self->{'f'} == $newton;
+    $self->{'f'} = $newton;
+    emit $self->forceChanged($self->{'f'});
 }
 
 sub shoot {
     my $self = shift;
 
-    return if $$self{'shooting'};
+    return if $self->{'shooting'};
     @$self{'timerCount', 'shoot_ang', 'shoot_f', 'shooting'} =
 	(0, $$self{'ang'}, $$self{'f'}, 1);
     $self->startTimer(50);
@@ -72,25 +64,25 @@ sub newTarget {
     my $self = shift;
 
     $self->erase($self->targetRect());
-    $$self{'target'} = new QPoint(200 + rand(65536) % 190,
-				  10  + rand(65536) % 255);
+    $self->{'target'} = QPoint->new(200 + rand(65536) % 190,
+				    10  + rand(65536) % 255);
     $self->repaint($self->targetRect());
 }
 
 sub setGameOver {
     my $self = shift;
 
-    return if $$self{'gameEnded'};
-    $self->stopShooting() if $$self{'shooting'};
-    $$self{'gameEnded'} = 1;
+    return if $self->{'gameEnded'};
+    $self->stopShooting() if $self->{'shooting'};
+    $self->{'gameEnded'} = 1;
     $self->repaint();
 }
 
 sub restartGame {
     my $self = shift;
 
-    $self->stopShooting() if $$self{'shooting'};
-    $$self{'gameEnded'} = 0;
+    $self->stopShooting() if $self->{'shooting'};
+    $self->{'gameEnded'} = 0;
     $self->repaint();
 }
 
@@ -98,7 +90,7 @@ sub timerEvent {
     my $self = shift;
 
     $self->erase($self->shotRect());
-    $$self{'timerCount'}++;
+    $self->{'timerCount'}++;
 
     my $shotR = $self->shotRect();
 
@@ -119,14 +111,14 @@ sub timerEvent {
 sub paintEvent {
     my $self = shift;
     my $updateR = shift->rect();
-    my $p = new QPainter;
+    my $p = QPainter->new;
     $p->begin($self);
 
     $self->paintCannon($p) if $updateR->intersects($self->cannonRect());
     $self->paintBarrier($p) if $updateR->intersects($self->barrierRect());
-    if($$self{'gameEnded'}) {
-	$p->setPen($black);
-	$p->setFont(new QFont('Courier', 48, $Weight{Bold}));
+    if($self->{'gameEnded'}) {
+	$p->setPen($Color{Black});
+	$p->setFont(QFont->new('Courier', 48, $Weight{Bold}));
 	$p->drawText($self->rect(), $Align{Center}, 'Game Over');
     } else {
 	$self->paintShot($p) if $self->isShooting() &&
@@ -141,32 +133,32 @@ sub mousePressEvent {
     my $e = shift;
 
     return if $e->button() != $Button{Left};
-    $$self{'barrelPressed'} = 1 if $self->barrelHit($e->pos());
+    $self->{'barrelPressed'} = 1 if $self->barrelHit($e->pos());
 }
 
 sub mouseMoveEvent {
     my $self = shift;
     my $e = shift;
 
-    return unless $$self{'barrelPressed'};
+    return unless $self->{'barrelPressed'};
     my $pnt = $e->pos();
     $pnt->setX(1) if $pnt->x() <= 0;
     $pnt->setY($self->height() - 1) if $pnt->y() >= $self->height();
     my $rad = atan(($self->rect()->bottom() - $pnt->y()) / $pnt->x());
-    $self->setAngle(qRound($rad*180/3.14159265));
+    $self->setAngle($rad*180/3.14159265);
 }
 
 sub mouseReleaseEvent {
     my $self = shift;
     my $e = shift;
 
-    $$self{'barrelPressed'} = 0 if $e->button() == $Button{Left};
+    $self->{'barrelPressed'} = 0 if $e->button() == $Button{Left};
 }
 
 sub stopShooting {
     my $self = shift;
 
-    $$self{'shooting'} = 0;
+    $self->{'shooting'} = 0;
     $self->killTimers();
 }
 
@@ -174,7 +166,7 @@ sub paintShot {
     my $self = shift;
     my $p = shift;
 
-    $p->setBrush($black);
+    $p->setBrush($Color{Black});
     $p->setPen($Pen{None});
     $p->drawRect($self->shotRect());
 }
@@ -183,8 +175,8 @@ sub paintTarget {
     my $self = shift;
     my $p = shift;
 
-    $p->setBrush($red);
-    $p->setPen($black);
+    $p->setBrush($Color{Red});
+    $p->setPen($Color{Black});
     $p->drawRect($self->targetRect());
 }
 
@@ -192,29 +184,29 @@ sub paintBarrier {
     my $self = shift;
     my $p = shift;
 
-    $p->setBrush($yellow);
-    $p->setPen($black);
+    $p->setBrush($Color{Yellow});
+    $p->setPen($Color{Black});
     $p->drawRect($self->barrierRect());
 }
 
-$barrel_rect = new QRect(33, -4, 15, 8);
+$barrel_rect = QRect->new(33, -4, 15, 8);
 
 sub paintCannon {
     my $self = shift;
     my $p = shift;
     my $cr = $self->cannonRect();
-    my $pix = new QPixmap($cr->size());
-    my $tmp = new QPainter;
+    my $pix = QPixmap->new($cr->size());
+    my $tmp = QPainter->new;
 
     $pix->fill($self, $cr->topLeft());
 
     $tmp->begin($pix);
-    $tmp->setBrush($blue);
+    $tmp->setBrush($Color{Blue});
     $tmp->setPen($Pen{None});
 
     $tmp->translate(0, $pix->height() - 1);
-    $tmp->drawPie(new QRect(-35, -35, 70, 70), 0, 90*16);
-    $tmp->rotate(-$$self{'ang'});
+    $tmp->drawPie(QRect->new(-35, -35, 70, 70), 0, 90*16);
+    $tmp->rotate(-$self->{'ang'});
     $tmp->drawRect($barrel_rect);
     $tmp->end();
 
@@ -223,7 +215,7 @@ sub paintCannon {
 
 sub cannonRect {
     my $self = shift;
-    my $r = new QRect(0, 0, 50, 50);
+    my $r = QRect->new(0, 0, 50, 50);
 
     $r->moveBottomLeft($self->rect()->bottomLeft());
     return $r;
@@ -234,9 +226,9 @@ sub shotRect {
 
     my $gravity  = 4;
 
-    my $time     = $$self{'timerCount'}/4.0;
-    my $velocity = $$self{'shoot_f'}/0.7;
-    my $radians  = $$self{'shoot_ang'}*3.14159265/180;
+    my $time     = $self->{'timerCount'}/4.0;
+    my $velocity = $self->{'shoot_f'}/0.7;
+    my $radians  = $self->{'shoot_ang'}*3.14159265/180;
 
     my $velx = $velocity*cos($radians);
     my $vely = $velocity*sin($radians);
@@ -245,34 +237,34 @@ sub shotRect {
     my $x    = $x0 + $velx*$time;
     my $y    = $y0 + $vely*$time - $gravity*$time*$time;
 
-    my $r = new QRect(0, 0, 6, 6);
-    $r->moveCenter(new QPoint(qRound($x), $self->height() - 1 - qRound($y)));
+    my $r = QRect->new(0, 0, 6, 6);
+    $r->moveCenter(QPoint->new($x, $self->height() - 1 - $y));
     return $r;
 }
 
 sub targetRect {
     my $self = shift;
-    my $target = $$self{'target'};
-    my $r = new QRect(0, 0, 20, 10);
+    my $target = $self->{'target'};
+    my $r = QRect->new(0, 0, 20, 10);
 
-    $r->moveCenter(new QPoint($target->x(), $self->height() - 1 -
-			      $target->y()));
+    $r->moveCenter(QPoint->new($target->x(), $self->height() - 1 -
+			       $target->y()));
     return $r;
 }
 
 sub barrierRect {
     my $self = shift;
 
-    return new QRect(145, $self->height() - 100, 15, 100);
+    return QRect->new(145, $self->height() - 100, 15, 100);
 }
 
 sub barrelHit {
     my $self = shift;
     my $p = shift;
-    my $mtx = new QWMatrix;
+    my $mtx = QWMatrix->new;
 
     $mtx->translate(0, $self->height() - 1);
-    $mtx->rotate(-$$self{'ang'});
+    $mtx->rotate(-$self->{'ang'});
     $mtx = $mtx->invert();
     return $barrel_rect->contains($mtx->map($p));
 }
